
-- Global table to hold values that are needed to be accessed in the different files
XRGA = XRGA or {}

-- Some useful information on this addon - only need to change this
XRGA.AddonInfo = {
	Name = "XrysGatherer",
	Version = "1.0.4",
	Prefix = "XRGA",
	SavedVars = "XrysGatherer_SavedVariables"
}

-- Get the player's current position, resetting the map as required ( on first player activated and node gathering )
function XRGA:GetPlayerPosition(setMap)
 	local zone,xPos,yPos,zPos,heading
 	if setMap then 
 		SetMapToPlayerLocation() 
 	end 	
	zone = GetMapName()
 	xPos,yPos,zPos = GetMapPlayerPosition("player")
 	heading = GetPlayerCameraHeading()
 	return zone,xPos,yPos,zPos,heading
 end

-- Remove the trailing ^? from the itemNames
function XRGA:FixItemName(itemName)
	local startPos,endPos = string.find(itemName,"^",1,true)
	if startPos then
		itemName = string.sub(itemName,1,startPos-1)
	end
	return itemName
end

-- Check if value exists in the table
function XRGA:FindTableIndex(table,value)
	for i,v in ipairs(table) do
		if v == value then
			return true,i
		end
	end
	return false
end

-- Check if the node/item exists on the map within 0.01 of the x and y positions
function XRGA:DataExists(isNode,Name,Map,xPos,yPos)
	if not Name or not Map or not xPos or not yPos then return false end
    for default,sv in pairs(XrysGatherer_SavedVariables) do 
		for account,accountv in pairs(sv) do
			for accountWide,acWideV in pairs(accountv) do
				for index,data in pairs(acWideV) do
	    			if index == "NodeData" then	    				
						for interactionTimeStamp,interactionData in pairs(data) do
							if interactionTimeStamp ~= "version" then
								if not interactionData then return false end
								if not interactionData.Items then return false end
								if interactionData.MapName == Map then
									local x,y = interactionData.X,interactionData.Y
									if math.abs(xPos - x) < 0.01 and math.abs(yPos - y) < 0.01 then 
										if isNode then
											if interactionData.Name == Name then
												return true
											end
										else
											for itemIndex,itemData in pairs(interactionData.Items) do
												if itemData.Item == Name then 
													return true 
												end
											end
										end
									end
								end
							end
						end
					end
				end
			end
		end
	end	
	return false
end

-- Build tables containing tradeskill details for use with the map pins.
function XRGA:InitTradeSkillInfo()

	local TradeSkills = {}
	local TradeSkillNames = {}

	local skillType,skillIndex = GetCraftingSkillLineIndices(CRAFTING_TYPE_ALCHEMY)
	local skillName,skillRank  = GetSkillLineInfo(skillType, skillIndex) 
	local abilityName,abilityIcon = GetSkillAbilityInfo(skillType, skillIndex, 1) 
	TradeSkills[CRAFTING_TYPE_ALCHEMY] = { Name = skillName, Icon = abilityIcon }
  
	skillType,skillIndex = GetCraftingSkillLineIndices(CRAFTING_TYPE_BLACKSMITHING)
	skillName,skillRank  = GetSkillLineInfo(skillType, skillIndex) 
	abilityName,abilityIcon = GetSkillAbilityInfo(skillType, skillIndex, 1) 
	TradeSkills[CRAFTING_TYPE_BLACKSMITHING] = 	{ Name = skillName, Icon = abilityIcon }


	skillType,skillIndex = GetCraftingSkillLineIndices(CRAFTING_TYPE_CLOTHIER)
	skillName,skillRank  = GetSkillLineInfo(skillType, skillIndex) 
	abilityName,abilityIcon = GetSkillAbilityInfo(skillType, skillIndex, 1) 
	TradeSkills[CRAFTING_TYPE_CLOTHIER] = 	{ Name = skillName, Icon = abilityIcon }

	skillType,skillIndex = GetCraftingSkillLineIndices(CRAFTING_TYPE_ENCHANTING)
	skillName,skillRank  = GetSkillLineInfo(skillType, skillIndex) 
	abilityName,abilityIcon = GetSkillAbilityInfo(skillType, skillIndex, 1) 
	TradeSkills[CRAFTING_TYPE_ENCHANTING] = 	{ Name = skillName, Icon = abilityIcon }
  
	skillType,skillIndex = GetCraftingSkillLineIndices(CRAFTING_TYPE_PROVISIONING)
	skillName,skillRank  = GetSkillLineInfo(skillType, skillIndex) 
	abilityName,abilityIcon = GetSkillAbilityInfo(skillType, skillIndex, 1) 
	TradeSkills[CRAFTING_TYPE_PROVISIONING] = 	{ Name = skillName, Icon = abilityIcon }
    
	skillType,skillIndex = GetCraftingSkillLineIndices(CRAFTING_TYPE_WOODWORKING)
	skillName,skillRank  = GetSkillLineInfo(skillType, skillIndex) 
	abilityName,abilityIcon = GetSkillAbilityInfo(skillType, skillIndex, 1) 
	TradeSkills[CRAFTING_TYPE_WOODWORKING] = 	{ Name = skillName, Icon = abilityIcon }

	for i,v in ipairs(TradeSkills) do
		table.insert(TradeSkillNames,v.Name)
	end

	return TradeSkills,TradeSkillNames
end
