local TradeSkills
local TradeSkillNames

-- Initialise the History Window
function XrysGathererHistory_Initialise(self)

	local ZoneData = {}
	local NodeData = {}
	local TradeSkillData = {}

	local allText = XRGALocaleString["ALL COMBO"]
	local noneText = XRGALocaleString["NONE COMBO"]

	-- Enable easy access to controls
    self.Info = self:GetNamedChild( '_Info' )
    self.Close = self:GetNamedChild( '_Close' )
    self.Refresh = self:GetNamedChild( '_Refresh' )
    self.Refresh:SetFont("ZoFontGameLargeBoldShadow")
	self.Caption = self:GetNamedChild( '_Caption' )
	self.Caption:SetFont("ZoFontHeader3")

	-- Create the Combo Boxes DropDowns
    self.CreateDropDown = function(self,name,caption,default)
    	local comboBox = self:GetNamedChild(name)
	    comboBox.Caption = self:GetNamedChild(name.."Caption")
	    comboBox.Caption:SetFont("ZoFontGameLarge")
	    comboBox.Caption:SetText(caption)

    	local dropDown = ZO_ComboBox_ObjectFromContainer( comboBox )
	    dropDown:SetSelectedItemFont( 'ZoFontGameLarge' )
	    dropDown:SetDropdownFont( 'ZoFontGame' )
	    dropDown:SetSpacing( 8 )
	    dropDown.SelectedItem = default
	    dropDown:SetSelectedItem( dropDown.SelectedItem )
	    dropDown.Button = self:GetNamedChild(name.."OpenDropdown")
    	return dropDown
	end

	-- Fill the Combo Boxes with data, optionally with ALL and NONE options
    self.FillComboBoxWithData = function(self,dropDown,Data,allowAll,allowNone)
		table.sort(Data)
		dropDown:ClearItems()
		local allowAllEntry = dropDown:CreateItemEntry( allText, function( ... ) dropDown.SelectedItem = allText end )
		if allowAll then dropDown:AddItem( allowAllEntry ) end
		local allowNoneEntry = dropDown:CreateItemEntry( noneText, function( ... ) dropDown.SelectedItem = noneText end )
		if allowNone then dropDown:AddItem( allowNoneEntry ) end
		for i,v in pairs(Data) do
			local itemEntry = dropDown:CreateItemEntry( v, function( ... ) dropDown.SelectedItem = v end )
	    	dropDown:AddItem( itemEntry )
		end
		if allowAll then 
			dropDown.SelectedItem = allText
		elseif allowNone then 
			dropDown.SelectedItem = noneText
		else
			dropDown.SelectedItem = nil
		end
		dropDown:SetSelectedItem(dropDown.SelectedItem) 
	end

	-- Update the List dependant on what combo box settings there are
	self.RefreshDisplay = function(self)

		self.Info:Clear()

		local selZone = self.ZonedropDown.SelectedItem
		local selNode = self.NodedropDown.SelectedItem
		local selTradeSkill = self.TradeSkilldropDown.SelectedItem
		local allZones = selZone == allText or selZone == nil or selZone == ""
		local allNodes = selNode == allText or selNode == nil or selNode == ""
		local allTradeSkills = selTradeSkill == allText or selTradeSkill == nil or selTradeSkill == ""
		local noTradeSkills = selTradeSkill == noneText
		local index = 0


		local nodeInfo = {}
		local itemInfo = {}
	    for default,sv in pairs(XrysGatherer_SavedVariables) do 
			for account,accountv in pairs(sv) do
				for accountWide,acWideV in pairs(accountv) do
					for i,v in pairs(acWideV) do
						if i == "ItemData" then itemInfo = v end
						if i == "NodeData" then nodeInfo = v end
					end
				end
			end
		end

		for nodeTimeStamp,nodeData in pairs(nodeInfo) do
			if nodeTimeStamp ~= "version" and type(nodeData.Items) == "table" then
				local nodeZone = nodeData.MapName
				local nodeName = nodeData.Name
				local nodeX = nodeData.X
				local nodeY = nodeData.Y				
				for itemIndex,itemData in pairs(nodeData.Items) do
					if type(itemData) == "table" then
						local itemName = itemData.Item
						local itemTrade = itemInfo[itemName].TradeSkill
						local itemType = itemInfo[itemName].ItemType
						local itemLink = itemInfo[itemName].Link	
						if itemTrade > 0 and allTradeSkills or selTradeSkill and selTradeSkill == TradeSkillNames[itemTrade] then 
							if allZones or selZone and selZone == nodeZone then
								if allNodes or selNode and selNode == nodeName then
									index = index + 1													
									self.Info:AddMessage(string.format("%d. %s [%s] %s - %s : %s (%0.02f, %0.02f)",index,TradeSkillNames[itemTrade],GetString(_G["SI_ITEMTYPE"..itemType]),itemLink,nodeName,nodeZone,nodeX,nodeY))
								end
							end
						end
					end
				end
			end
		end
	end

	-- Initialise the Combo Boxes and refresh the History Data
	self.InitialiseDisplay = function(self)

	    self.Refresh:SetText(XRGALocaleString["REFRESH DATA"])
		self.Caption:SetText(XRGA.AddonInfo.Name .. " (" .. XRGA.AddonInfo.Version .. ") - "..XRGALocaleString["HARVEST HISTORY"])

		ZoneData = {}
		TradeSkillData = {}
		NodeData = {}
		self.Info:Clear()

		local itemInfo, nodeInfo
	    for default,sv in pairs(XrysGatherer_SavedVariables) do 
			for account,accountv in pairs(sv) do
				for accountWide,acWideV in pairs(accountv) do
					for i,v in pairs(acWideV) do
						if i == "ItemData" then itemInfo = v end
						if i == "NodeData" then nodeInfo = v end
					end
				end
			end
		end

		for itemName,itemData in pairs(itemInfo) do
			if itemName ~= "version" and itemData.TradeSkill and itemData.TradeSkill > 0 then
				local nodeTrade = TradeSkills[itemData.TradeSkill].Name
				if not XRGA:FindTableIndex(TradeSkillData,nodeTrade) then table.insert(TradeSkillData,nodeTrade) end
			end
		end

		for nodeTimeStamp,nodeData in pairs(nodeInfo) do
			if nodeTimeStamp ~= "version" then
				local nodeZone = nodeData.MapName
				local nodeName = nodeData.Name
				if not XRGA:FindTableIndex(ZoneData,nodeZone) then table.insert(ZoneData,nodeZone) end
				if not XRGA:FindTableIndex(NodeData,nodeName) then table.insert(NodeData,nodeName) end
			end
		end

		self:FillComboBoxWithData(self.ZonedropDown,ZoneData,true,false)
		self:FillComboBoxWithData(self.NodedropDown,NodeData,true,false)
		self:FillComboBoxWithData(self.TradeSkilldropDown,TradeSkillData,true,true)
	end

	-- Create the DropDowns
    self.ZonedropDown = self:CreateDropDown("_ComboBoxZone",XRGALocaleString["ZONE"],allText)
    self.TradeSkilldropDown = self:CreateDropDown("_ComboBoxTradeSkill",XRGALocaleString["TRADESKILL"],allText)
    self.NodedropDown = self:CreateDropDown("_ComboBoxNode",XRGALocaleString["NODE"],allText)

    -- Hide the frame
    self:SetHidden(true)
end

local function PlayerActivated(eventID)
	EVENT_MANAGER:UnregisterForEvent(XRGA.AddonInfo.Prefix.."_History",eventID)
	TradeSkills,TradeSkillNames = XRGA:InitTradeSkillInfo()
end

local function AddOnLoaded(eventID,addonName)
	if addonName == XRGA.AddonInfo.Name then
		EVENT_MANAGER:UnregisterForEvent(XRGA.AddonInfo.Prefix.."_History",eventID)
		EVENT_MANAGER:RegisterForEvent(XRGA.AddonInfo.Prefix.."_History",EVENT_PLAYER_ACTIVATED,PlayerActivated)
	end
end

EVENT_MANAGER:RegisterForEvent(XRGA.AddonInfo.Prefix.."_History",EVENT_ADD_ON_LOADED,AddOnLoaded)

