local TradeSkills
local TradeSkillNames

local SVData = {}


-- Initialise the History Window with active data
function XrysGathererImport_Initialise(self)

	-- Enable easy access to controls
    self.Info = self:GetNamedChild( '_Info' )
    self.Close = self:GetNamedChild( '_Close' )
    self.Refresh = self:GetNamedChild( '_Refresh' )
    self.Refresh:SetFont("ZoFontGameLargeBoldShadow")
    self.Import = self:GetNamedChild( '_Import' )
    self.Import:SetFont("ZoFontGameLargeBoldShadow")
	self.Caption = self:GetNamedChild( '_Caption' )
	self.Caption:SetFont("ZoFontHeader3")

	-- Update the List dependant on what combo box settings there are
	self.RefreshDisplay = function(self)
		self.Info:Clear()
		local index = 0
		if not XrysGatherer_ImportData then return end

		local nodeInfo = {}
		local itemInfo = {}
	    for default,sv in pairs(XrysGatherer_ImportData) do 
			for account,accountv in pairs(sv) do
				for accountWide,acWideV in pairs(accountv) do
					for i,v in pairs(acWideV) do
						if i == "ItemData" then itemInfo = v end
						if i == "NodeData" then nodeInfo = v end
					end
				end
			end
		end

		for nodeTimeStamp,nodeData in pairs(nodeInfo) do
			if nodeTimeStamp ~= "version" then
				local nodeZone = nodeData.MapName
				local nodeName = nodeData.Name
				local nodeX = nodeData.X
				local nodeY = nodeData.Y
				for itemIndex,itemData in pairs(nodeData.Items) do
					local itemName = itemData.Item
					local itemTrade = itemInfo[itemName].TradeSkill
					local itemType = itemInfo[itemName].ItemType
					local itemLink = itemInfo[itemName].Link	
					if itemTrade > 0 then 
						if not XRGA:DataExists(true,nodeName,nodeZone,nodeX,nodeY) then
							index = index + 1													
							self.Info:AddMessage(string.format("%d. %s [%s] %s - %s : %s (%0.02f, %0.02f)",index,TradeSkillNames[itemTrade],GetString(_G["SI_ITEMTYPE"..itemType]),itemName,nodeName,nodeZone,nodeX,nodeY))
						end
					end
				end
			end
		end
	end

	self.ImportData = function(self)
		self.Info:Clear()
		if not XrysGatherer_ImportData then return end

		local nodeInfo = {}
		local itemInfo = {}
		local newTimeStamp
	    for default,sv in pairs(XrysGatherer_ImportData) do 
			for account,accountv in pairs(sv) do
				for accountWide,acWideV in pairs(accountv) do
					for i,v in pairs(acWideV) do
						if i == "ItemData" then itemInfo = v end
						if i == "NodeData" then nodeInfo = v end
					end
				end
			end
		end

		for nodeTimeStamp,nodeData in pairs(nodeInfo) do
			if nodeTimeStamp ~= "version" then				
				newTimeStamp = nodeTimeStamp				
				if SVData and SVData["NodeData"] and SVData["NodeData"][newTimeStamp] then
					-- If the timestamp already exists then grab a later version before continuing
					while (SVData["NodeData"][newTimeStamp]) do
						newTimeStamp = newTimeStamp + 1
					end
				end
				local nodeZone = nodeData.MapName
				local nodeName = nodeData.Name
				local nodeX = nodeData.X
				local nodeY = nodeData.Y
				for itemIndex,itemData in pairs(nodeData.Items) do
					local itemName = itemData.Item
					local itemTrade = itemInfo[itemName].TradeSkill
					local itemType = itemInfo[itemName].ItemType
					local itemLink = itemInfo[itemName].Link	

					-- Just in case a non tradeskill item sneaked in. 
					if itemTrade > 0 then 
						if not XRGA:DataExists(true,nodeName,nodeZone,nodeX,nodeY) then
							SVData = SVData or {}
							SVData["NodeData"] = SVData["NodeData"] or {}
							SVData["NodeData"][newTimeStamp] = SVData["NodeData"][newTimeStamp] or {}
							SVData["NodeData"][newTimeStamp].Name = nodeData.Name
							SVData["NodeData"][newTimeStamp].Type = nodeData.Type
							SVData["NodeData"][newTimeStamp].Action = nodeData.Action
							SVData["NodeData"][newTimeStamp].MapName = nodeData.MapName
							SVData["NodeData"][newTimeStamp].X = nodeData.X
							SVData["NodeData"][newTimeStamp].Y = nodeData.Y
							SVData["NodeData"][newTimeStamp].Z = nodeData.Z
							SVData["NodeData"][newTimeStamp].Heading = nodeData.Heading
							SVData["NodeData"][newTimeStamp].Items = {}

							table.insert(SVData["NodeData"][newTimeStamp].Items,{
								Item = itemData.Item,
								Count = itemData.Count,
								Value = itemData.Value,
							})

							SVData["ItemData"] = SVData["ItemData"] or {}
							SVData["ItemData"][itemName] = SVData["ItemData"][itemName] or {}
							SVData["ItemData"][itemName].Acquisitions = SVData["ItemData"][itemName].Acquisitions or {}

							SVData["ItemData"][itemName].Icon = itemInfo[itemName].Icon
							SVData["ItemData"][itemName].Quality = itemInfo[itemName].Quality
							SVData["ItemData"][itemName].Link = itemInfo[itemName].Link
							SVData["ItemData"][itemName].FilterType = itemInfo[itemName].FilterType
							SVData["ItemData"][itemName].TradeSkill = itemInfo[itemName].TradeSkill
							SVData["ItemData"][itemName].ItemType = itemInfo[itemName].ItemType

							if SVData["NodeData"][newTimeStamp] and itemTrade ~= CRAFTING_TYPE_INVALID then
								table.insert(SVData["ItemData"][itemName].Acquisitions,{
									TimeStamp = newTimeStamp,
								})	

								local pinType = XRGA.AddonInfo.Prefix.."_"..TradeSkills[itemTrade].Name

								local pinKey = { 
									Node = SVData["NodeData"][newTimeStamp].Name, 
									Map = SVData["NodeData"][newTimeStamp].MapName, 
									X = SVData["NodeData"][newTimeStamp].X, 
									Y = SVData["NodeData"][newTimeStamp].Y, 
									Item = itemName, 
									Icon = SVData["ItemData"][itemName].Icon, 
									Type = SVData["ItemData"][itemName].ItemType, 
									TradeSkill = SVData["ItemData"][itemName].TradeSkill, 
									Link = SVData["ItemData"][itemName].Link 
								}
								XRGA:CreatePin(pinType,pinKey,SVData["NodeData"][newTimeStamp].MapName,SVData["NodeData"][newTimeStamp].X,SVData["NodeData"][newTimeStamp].Y,nil)
								self.Info:AddMessage(string.format("[%s] %s - %s : %s (%0.02f, %0.02f)",XRGALocaleString["IMPORTED"],itemName,nodeName,nodeZone,nodeX,nodeY))
							else
								self.Info:AddMessage(string.format("[%s] %s [%s] %s - %s : %s (%0.02f, %0.02f)",XRGALocaleString["IMPORTED"],TradeSkillNames[itemTrade],GetString(_G["SI_ITEMTYPE"..itemType]),itemName,nodeName,nodeZone,nodeX,nodeY))
							end

						end
					end
				end
			end
		end
	end

	-- Initialise the controls and refresh the History Data
	self.InitialiseDisplay = function(self)
	    self.Refresh:SetText(XRGALocaleString["REFRESH DATA"])
	    self.Import:SetText(XRGALocaleString["IMPORT DATA"])
		self.Caption:SetText(XRGA.AddonInfo.Name .. " (" .. XRGA.AddonInfo.Version .. ") - ".. XRGALocaleString["DATA TO IMPORT"])
		self.Info:Clear()
	end

    -- Hide the frame
    self:SetHidden(true)
end


local function PlayerActivated(eventID)
	EVENT_MANAGER:UnregisterForEvent(XRGA.AddonInfo.Prefix.."_Import",eventID)
	TradeSkills,TradeSkillNames = XRGA:InitTradeSkillInfo()
end

local function AddOnLoaded(eventID,addonName)
	if addonName == XRGA.AddonInfo.Name then
		EVENT_MANAGER:UnregisterForEvent(XRGA.AddonInfo.Prefix.."_Import",eventID)
		SVData = XRGA:InitialiseSV()
		EVENT_MANAGER:RegisterForEvent(XRGA.AddonInfo.Prefix.."_Import",EVENT_PLAYER_ACTIVATED,PlayerActivated)
	end
end

EVENT_MANAGER:RegisterForEvent(XRGA.AddonInfo.Prefix.."_Import",EVENT_ADD_ON_LOADED,AddOnLoaded)

