
-- Used in the the gathering process
local isHarvesting = false
local wasHarvesting = false
local isNewNode = false
local interactionTimeStamp
local OldItemData = {}
local harvestInteractionInfo = {}
local lootTargetInfo = {}
local harvestLocationInfo = {}
local debugOtherLoot = false			-- set this to true if you want to see other people's gathering ( not fully tested )

local SVData = {}

local TradeSkills
local TradeSkillNames

local function CloseLoot(eventID,...)
	if not wasHarvesting then return end
	-- We've finished looting so we must have finished harvesting too
	local isHarvesting = false
	local wasHarvesting = false
end

-- Monitor receipt of loot so only your data is recorded in your records
local function ReceiveLoot(eventID, receivedBy, item, quantity, itemSound, lootType, self)
	if not wasHarvesting then return end

	-- Grab the data stored earlier from the slot update event
	local itemName = OldItemData["Name"]
	local itemIcon = OldItemData["Icon"]
	local itemQuality = OldItemData["Quality"]
	local itemLink = OldItemData["Link"]
	local filterType = OldItemData["FilterType"]
	local tradeSkill = OldItemData["TradeSkill"]
	local itemType = OldItemData["ItemType"]
	local interactionTimeStamp = OldItemData["TimeStamp"]

	-- If this is not a tradeskill item then don't process further
	if tradeSkill == CRAFTING_TYPE_INVALID then return end

	-- If this is not a valid filterType then don't process further
	if filterType == 0 then return end

	-- if this is not a valid itemType then don't process further
	if itemType == ITEMTYPE_NONE then return end

	-- If we don't have an item then don't process further
	if not itemName then return end

	if debugOtherLoot then 
		CHAT_SYSTEM:AddMessage(string.format("ReceiveLoot: Who: %s, What: %s, How Many: %d, Self: %s",receivedBy,item,quantity,tostring(self)))
		CHAT_SYSTEM:AddMessage(string.format("ReceiveLoot (via SlotUpdate) : Item: %s, TradeSkill: %s, ItemType: %s, FilterType: %s",itemName,TradeSkillNames[tradeSkill],GetString(_G["SI_ITEMTYPE"..itemType]),GetString(_G["SI_ITEMFILTERTYPE"..filterType])))
		CHAT_SYSTEM:AddMessage(string.format("ReceiveLoot (via NodeInteract) : Map: %s, X: %0.3f, Y:%0.3f, Node: %s",harvestLocationInfo.Map, harvestLocationInfo.X,harvestLocationInfo.Y,lootTargetInfo.Name))
	end

	-- Now that the debug messages are displayed we don't want to do anything else with other peoples data yet.
	if not self then return end

	-- Add Item Looted to Node Item List for this interaction if we created an interaction table for it
	if SVData["NodeData"][interactionTimeStamp] and SVData["NodeData"][interactionTimeStamp].Items then
		table.insert(SVData["NodeData"][interactionTimeStamp].Items,{
			Item = itemName,
			Count = quantity,
		})
	end

	-- Store details in the saved variables file
	SVData = SVData or {}
	SVData["ItemData"] = SVData["ItemData"] or {}
	SVData["ItemData"][itemName] = SVData["ItemData"][itemName] or {}
	SVData["ItemData"][itemName].Acquisitions = SVData["ItemData"][itemName].Acquisitions or {}	

	SVData["ItemData"][itemName].Icon = itemIcon
	SVData["ItemData"][itemName].Quality = itemQuality
	SVData["ItemData"][itemName].Link = itemLink
	SVData["ItemData"][itemName].FilterType = filterType
	SVData["ItemData"][itemName].TradeSkill = tradeSkill
	SVData["ItemData"][itemName].ItemType = itemType

	table.insert(SVData["ItemData"][itemName].Acquisitions,{
		TimeStamp = interactionTimeStamp,
	})	

	-- Set the pin details for this harvest node
	local pinType = XRGA.AddonInfo.Prefix.."_"..TradeSkills[tradeSkill].Name
	local pinKey = { 
			Map = harvestLocationInfo.Map, 
			X = harvestLocationInfo.X, 
			Y = harvestLocationInfo.Y, 
			Item = itemName, 
			Icon = itemIcon, 
			Type = itemType, 
			Node = lootTargetInfo.Name, 
			TradeSkill = tradeSkill, 
			Link = itemLink 
		}

	-- Create the pin for this location and type
	XRGA:CreatePin(pinType,pinKey,pinKey.Map,pinKey.X,pinKey.Y,nil)

	if not SVData["NodeData"][interactionTimeStamp] then
		if not isNewNode then
			if SVData["Options"]["Verbose"]["Old Node"] then
				CHAT_SYSTEM:AddMessage(string.format("%s %s [%s] - %s : %s (%0.02f, %0.02f)",XRGALocaleString["OLD NODE"],TradeSkills[tradeSkill].Name,GetString(_G["SI_ITEMTYPE"..itemType]),pinKey.Node,pinKey.Map,pinKey.X,pinKey.Y))
			end
		end

	elseif SVData["NodeData"][interactionTimeStamp] then
		if isNewNode then
			if SVData["Options"]["Verbose"]["New Node"] then
				CHAT_SYSTEM:AddMessage(string.format("%s %s [%s] - %s : %s (%0.02f, %0.02f)",XRGALocaleString["NEW NODE"],TradeSkills[tradeSkill].Name,GetString(_G["SI_ITEMTYPE"..itemType]), pinKey.Node,pinKey.Map,pinKey.X,pinKey.Y))
			end
		end
	end
end

-- Monitor loot as it is received after harvesting
local function SlotUpdate(eventID,bagID,slotID,isNew, itemSoundCategory, updateReason)

	if updateReason == INVENTORY_UPDATE_REASON_DURABILITY_CHANGE then return end
	if bagID == BAG_WORN then return end
	if not isNew then return end

	if isHarvesting then
		wasHarvesting = true
		isHarvesting = false
	end

	if not wasHarvesting then return end

	local mapName = harvestLocationInfo.Map
	local xPos = harvestLocationInfo.X
	local yPos = harvestLocationInfo.Y
	local zPos = harvestLocationInfo.Z
	local heading = harvestLocationInfo.Heading

	local targetName = harvestInteractionInfo[2] or "UNKNOWN"
	local targetType = 1
	local actionName = harvestInteractionInfo[1] or "HARVEST"
	lootTargetInfo = { Action = actionName, Name = targetName, Type = targetType }

	-- If this is an unknown harvest then ignore this harvest gathering session and proceed as normal
	if targetName == "UNKNOWN" then 
		wasHarvesting = false
		return 
	end

	-- Only add the data to the saved variables table if one doesn't already exist there
	if not XRGA:DataExists(true,targetName,mapName,xPos,yPos) then
		SVData = SVData or {}
		SVData["NodeData"] = SVData["NodeData"] or {}
		if not SVData["NodeData"][interactionTimeStamp] then
			SVData["NodeData"][interactionTimeStamp] = {}
			SVData["NodeData"][interactionTimeStamp].Name = targetName
			SVData["NodeData"][interactionTimeStamp].Type = targetType
			SVData["NodeData"][interactionTimeStamp].Action = actionName
			SVData["NodeData"][interactionTimeStamp].MapName = mapName
			SVData["NodeData"][interactionTimeStamp].X = xPos
			SVData["NodeData"][interactionTimeStamp].Y = yPos
			SVData["NodeData"][interactionTimeStamp].Z = zPos
			SVData["NodeData"][interactionTimeStamp].Heading = heading
			SVData["NodeData"][interactionTimeStamp].Items = {}
		end				 
		isNewNode = true
	else
		isNewNode = false
	end

	local itemName = GetItemName(bagID, slotID)
	itemName = XRGA:FixItemName(itemName)

	if not itemName then return end

	local filterType = GetItemFilterTypeInfo(bagID,slotID) 
	local tradeSkill, itemType, extraInfo1, extraInfo2, extraInfo3 = GetItemCraftingInfo(bagID,slotID)
	local itemLink = GetItemLink(bagID,slotID, LINK_STYLE_DEFAULT)
	local itemIcon, stackQty, sellPrice, meetsUsageRequirement, isLocked, equipType, itemStyle, itemQuality = GetItemInfo(bagID,slotID)

	-- Store data in array for later use so no one else can grab it.
	OldItemData = {
		["Name"] = itemName,
		["Icon"] = itemIcon,
		["Quality"] = itemQuality,
		["Link"] = itemLink,
		["FilterType"] = filterType,
		["TradeSkill"] = tradeSkill,
		["ItemType"] = itemType,
		["TimeStamp"] = interactionTimeStamp,
	}
end

-- Monitor Interactions with the Harvest Nodes
function XrysGatherer_InteractUpdate(self)

	-- Is player Interacting with something ?
	local isPlayerInteracting = IsPlayerInteractingWithObject() 
	if not isPlayerInteracting then 
		if wasHarvesting or isHarvesting then
			-- If player was interacting with something but now is not then reset interaction
			isHarvesting = false
			wasHarvesting = false
		end
		return 
	end

	-- Find out in what way
	local interactMode = GetInteractionType()

	if interactMode ~= INTERACTION_HARVEST then 
		-- If we are not harvesting then check if we were as we may be looting now
		if isHarvesting then
			wasHarvesting = true
			isHarvesting = false
			return 
		end
	else
		if not isHarvesting then

			-- We aren't harvesting yet but this is a harvesting interaction
			isHarvesting = true
			wasHarvesting = false
			lootTargetInfo = {}

			-- Get Interaction Info for harvest node
			harvestInteractionInfo = { GetGameCameraInteractableActionInfo() }  -- 	Action, Name, InteractBlocked, AdditionalInfo, ContextualInfo
			interactionTimeStamp = GetTimeStamp()

			-- Get the Players current location in the world
		 	local mapName,xPos,yPos,zPos,heading = XRGA:GetPlayerPosition(true)
			XrysGathererWindow.Map:SetText(string.format("%s",mapName))
			XrysGathererWindow.Coordinates:SetText(string.format("(%0.3f,%0.3f,%0.03f)",xPos,yPos,zPos))
			harvestLocationInfo = { Map = mapName, X = xPos, Y = yPos, Z = zPos, Heading = heading }

		else
			-- We are already harvesting
			return
		end
	end
end

local function PlayerActivated(eventID)
	EVENT_MANAGER:UnregisterForEvent(XRGA.AddonInfo.Prefix.."_NodeInteract",eventID)
	TradeSkills,TradeSkillNames = XRGA:InitTradeSkillInfo()
end

local function AddOnLoaded(eventID,addonName)
	if addonName == XRGA.AddonInfo.Name then
		EVENT_MANAGER:UnregisterForEvent(XRGA.AddonInfo.Prefix.."_NodeInteract",eventID)
		SVData = XRGA:InitialiseSV()
		EVENT_MANAGER:RegisterForEvent(XRGA.AddonInfo.Prefix.."_NodeInteract",EVENT_PLAYER_ACTIVATED,PlayerActivated)
		EVENT_MANAGER:RegisterForEvent(XRGA.AddonInfo.Prefix.."_NodeInteract",EVENT_INVENTORY_SINGLE_SLOT_UPDATE,SlotUpdate)	
		EVENT_MANAGER:RegisterForEvent(XRGA.AddonInfo.Prefix.."_NodeInteract",EVENT_LOOT_RECEIVED,ReceiveLoot)
		EVENT_MANAGER:RegisterForEvent(XRGA.AddonInfo.Prefix.."_NodeInteract",EVENT_LOOT_CLOSED,CloseLoot)
	end
end

EVENT_MANAGER:RegisterForEvent(XRGA.AddonInfo.Prefix.."_NodeInteract",EVENT_ADD_ON_LOADED,AddOnLoaded)

