
-- Update Routines for the Main Window
local updateTimer = 1
local lastLocationUpdate
function XrysGathererWindow_Update(self)

	lastLocationUpdate = lastLocationUpdate or 0

	local timeNow = GetTimeStamp()
	local timeDiff = GetDiffBetweenTimeStamps(timeNow,lastLocationUpdate)

	if timeDiff < updateTimer then return end

	local zone,xPos,yPos,zPos,heading = XRGA:GetPlayerPosition(false)
	XrysGathererWindow.Coordinates:SetText(string.format("(%0.3f,%0.3f,%0.03f)",xPos,yPos,zPos))

    lastLocationUpdate = GetTimeStamp()
end

-- Initialise the Main Window
function XrysGathererWindow_Initialise(self)

	-- Enable easy access to controls
    self.History = self:GetNamedChild( "_History" )    
    self.History:SetFont("ZoFontGameLargeBoldShadow")
    self.Import = self:GetNamedChild( "_Import" )
    self.Import:SetFont("ZoFontGameLargeBoldShadow")
	self.Options = self:GetNamedChild( "_Options" )
    self.Options:SetFont("ZoFontGameLargeBoldShadow")
	self.Caption = self:GetNamedChild( "_Caption" )
	self.Caption:SetFont("ZoFontGameLargeBoldShadow")
	self.Map = self:GetNamedChild( "_Map" )
	self.Map:SetFont("ZoFontGameLargeBoldShadow")
	self.Coordinates = self:GetNamedChild( "_Coordinates" )
	self.Coordinates:SetFont("ZoFontGameLargeBoldShadow")

	self.InitialiseDisplay = function(self)
	    self.History:SetText(XRGALocaleString["TOGGLE HISTORY"])
    	self.Import:SetText(XRGALocaleString["TOGGLE IMPORT"])
    	self.Options:SetText(XRGALocaleString["TOGGLE OPTIONS"])
		self.Caption:SetText(XRGA.AddonInfo.Name.." ("..XRGA.AddonInfo.Version..")")
	end

    -- Hide the frame
    self:SetHidden(true)
end

-- Process the slash commands
local function ProcessSlashCommands(option)

	-- Extract Options
    local options = {}
    local searchResult = { string.match(option,"^(%S*)%s*(.-)$") }
    for i,v in pairs(searchResult) do
        if (v ~= nil and v ~= "") then
            options[i] = string.lower(v)
        end
    end

    -- Show what slash commands are available
	if #options == 0 or options[1] == "help" then
		CHAT_SYSTEM:AddMessage(XRGALocaleString["SLASH TOGGLE"])
		return
	end

	-- Execute functionality based on user requests

	if options[1] == "toggle" then
		XrysGathererWindow:ToggleHidden()

	end
end

-- Initialise slash Commands
local function InitSlashCommands(...)
	SLASH_COMMANDS["/xrga"] = ProcessSlashCommands
end

-- If you change main zone 
local function ZoneUpdate(eventID,unitTag,newZoneName)
	if unitTag == "player" and newZoneName ~= "" then
		local zone,xPos,yPos,zPos,heading = XRGA:GetPlayerPosition(true)
		XrysGathererWindow.Map:SetText(string.format("%s",newZoneName))
		XrysGathererWindow.Coordinates:SetText(string.format("(%0.3f,%0.3f,%0.03f)",xPos,yPos,zPos))
	end
end

local function PlayerActivated(eventID)
	EVENT_MANAGER:UnregisterForEvent(XRGA.AddonInfo.Prefix.."_XrysGatherer",eventID)
	local locale = GetCVar("language.2") 
	if not XRGALocaleString then CHAT_SYSTEM:AddMessage(XRGALocaleString["LOCALE NOT LOADED"]..locale) end
	CHAT_SYSTEM:AddMessage(XRGA.AddonInfo.Name.." ("..XRGA.AddonInfo.Version..") - "..XRGALocaleString["LOCALE LOADED"])
	CHAT_SYSTEM:AddMessage(XRGALocaleString["SLASH TOGGLE"])
	InitSlashCommands()
	local zone,xPos,yPos,zPos,heading = XRGA:GetPlayerPosition(true)
	XrysGathererWindow.Map:SetText(string.format("%s",zone))
	XrysGathererWindow.Coordinates:SetText(string.format("(%0.3f,%0.3f,%0.03f)",xPos,yPos,zPos))
	EVENT_MANAGER:RegisterForEvent(XRGA.AddonInfo.Prefix.."_XrysGatherer",EVENT_ZONE_UPDATE,ZoneUpdate) 
end

local function AddOnLoaded(eventID,addonName)
	if addonName == XRGA.AddonInfo.Name then
		EVENT_MANAGER:UnregisterForEvent(XRGA.AddonInfo.Prefix.."_XrysGatherer",eventID)
		EVENT_MANAGER:RegisterForEvent(XRGA.AddonInfo.Prefix.."_XrysGatherer",EVENT_PLAYER_ACTIVATED,PlayerActivated)
	end
end

EVENT_MANAGER:RegisterForEvent(XRGA.AddonInfo.Prefix.."_XrysGatherer",EVENT_ADD_ON_LOADED,AddOnLoaded)
